unittest._WritelnDecorator

unittest :: _WritelnDecorator :: Class _WritelnDecorator |
[hide private]
[frames] | no frames]

# Class _WritelnDecorator

source code

    object --+
             |
            _WritelnDecorator

Used to decorate file-like objects with a handy 'writeln' method

Instance Methods | [hide private]
__getattr__(self, attr) | source code
__init__(self, stream) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
writeln(self, arg=None) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, stream) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)